Class: MetaTags::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/meta_tags/configuration.rb

Overview

MetaTags configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeConfiguration

Initializes a new instance of Configuration class.



50
51
52
# File 'lib/meta_tags/configuration.rb', line 50

def initialize
  reset_defaults!
end

Instance Attribute Details

#description_limitObject

How many characters to truncate description to.



19
20
21
# File 'lib/meta_tags/configuration.rb', line 19

def description_limit
  @description_limit
end

#keywords_limitObject

How many characters to truncate keywords to.



22
23
24
# File 'lib/meta_tags/configuration.rb', line 22

def keywords_limit
  @keywords_limit
end

#keywords_lowercaseObject

Should keywords be forced into lowercase?



28
29
30
# File 'lib/meta_tags/configuration.rb', line 28

def keywords_lowercase
  @keywords_lowercase
end

#keywords_separatorObject

Keywords separator - a string to join keywords with.



25
26
27
# File 'lib/meta_tags/configuration.rb', line 25

def keywords_separator
  @keywords_separator
end

#minify_outputObject

When true, the output will not include new line characters between meta tags. Default is false.



36
37
38
# File 'lib/meta_tags/configuration.rb', line 36

def minify_output
  @minify_output
end

#open_meta_tagsObject

Switches between open (<meta … >) and closed (<meta … />) meta tags. Default is true, which means “open”.



32
33
34
# File 'lib/meta_tags/configuration.rb', line 32

def open_meta_tags
  @open_meta_tags
end

#property_tagsObject (readonly)

Custom meta tags that should use the property attribute instead of name. An array of strings or symbols representing their names or name prefixes.



40
41
42
# File 'lib/meta_tags/configuration.rb', line 40

def property_tags
  @property_tags
end

Configure whether MetaTags should skip canonical links on pages with ‘noindex: true`. John Mueller has noted that mixing noindex and `rel=canonical` sends contradictory signals. www.reddit.com/r/TechSEO/comments/8yahdr/2_questions_about_the_canonical_tag/e2dey9i/



47
48
49
# File 'lib/meta_tags/configuration.rb', line 47

def skip_canonical_links_on_noindex
  @skip_canonical_links_on_noindex
end

#title_limitObject

How many characters to truncate title to.



7
8
9
# File 'lib/meta_tags/configuration.rb', line 7

def title_limit
  @title_limit
end

#title_tag_attributesObject

HTML attributes for the title tag.



10
11
12
# File 'lib/meta_tags/configuration.rb', line 10

def title_tag_attributes
  @title_tag_attributes
end

#truncate_on_natural_separatorObject

A string or regexp separator to truncate text at a natural break.



16
17
18
# File 'lib/meta_tags/configuration.rb', line 16

def truncate_on_natural_separator
  @truncate_on_natural_separator
end

#truncate_site_title_firstObject

Truncate site_title instead of title.



13
14
15
# File 'lib/meta_tags/configuration.rb', line 13

def truncate_site_title_first
  @truncate_site_title_first
end

Instance Method Details

#default_property_tagsArray<String>

Returns the default meta tag prefixes and names that use property.

Returns:

  • (Array<String>)

    default property tag names.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/meta_tags/configuration.rb', line 57

def default_property_tags
  [
    # App Links metadata https://developers.facebook.com/docs/applinks/metadata-reference
    "al",
    # Open Graph Markup https://developers.facebook.com/docs/sharing/webmasters#markup
    "fb",
    "og",
    # Facebook Open Graph object types https://developers.facebook.com/docs/reference/opengraph
    # These tags are matched as exact property names or namespace prefixes, so e.g.
    # 'restaurant' affects 'restaurant:category', 'restaurant:price_rating', and other
    # properties under that namespace.
    "article",
    "book",
    "books",
    "business",
    "fitness",
    "game",
    "music",
    "place",
    "product",
    "profile",
    "restaurant",
    "video"
  ].freeze
end

#open_meta_tags?Boolean

Indicates whether meta tags should be rendered with open tag syntax.

Returns:

  • (Boolean)

    true when open meta tags are enabled.



86
87
88
# File 'lib/meta_tags/configuration.rb', line 86

def open_meta_tags?
  !!open_meta_tags
end

#reset_defaults!void

This method returns an undefined value.

Restores the default configuration values.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/meta_tags/configuration.rb', line 93

def reset_defaults!
  @title_limit = 70
  @truncate_site_title_first = false
  @truncate_on_natural_separator = " "
  @title_tag_attributes = {}
  @description_limit = 300
  @keywords_limit = 255
  @keywords_separator = ", "
  @keywords_lowercase = true
  @property_tags = default_property_tags.dup
  @open_meta_tags = true
  @minify_output = false
  @skip_canonical_links_on_noindex = false
end