Class: MetaTags::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/meta_tags/configuration.rb,
sig/lib/meta_tags/configuration.rbs

Overview

MetaTags configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeConfiguration

Initializes a new instance of Configuration class.



49
50
51
# File 'lib/meta_tags/configuration.rb', line 49

def initialize
  reset_defaults!
end

Instance Attribute Details

#description_limitInteger

How many characters to truncate description to.

Returns:

  • (Integer)


19
20
21
# File 'lib/meta_tags/configuration.rb', line 19

def description_limit
  @description_limit
end

#keywords_limitInteger

How many characters to truncate keywords to.

Returns:

  • (Integer)


22
23
24
# File 'lib/meta_tags/configuration.rb', line 22

def keywords_limit
  @keywords_limit
end

#keywords_lowercaseBoolean

Should keywords forced into lowercase?

Returns:

  • (Boolean)


28
29
30
# File 'lib/meta_tags/configuration.rb', line 28

def keywords_lowercase
  @keywords_lowercase
end

#keywords_separatorString

Keywords separator - a string to join keywords with.

Returns:

  • (String)


25
26
27
# File 'lib/meta_tags/configuration.rb', line 25

def keywords_separator
  @keywords_separator
end

#minify_outputBoolean

When true, the output will not include new line characters between meta tags. Default is false.

Returns:

  • (Boolean)


36
37
38
# File 'lib/meta_tags/configuration.rb', line 36

def minify_output
  @minify_output
end

#open_meta_tagsBoolean

Switches between open (<meta ... >) and closed (<meta ... />) meta tags. Default is true, which means "open".

Returns:

  • (Boolean)


32
33
34
# File 'lib/meta_tags/configuration.rb', line 32

def open_meta_tags
  @open_meta_tags
end

#property_tagsArray[String | Symbol] (readonly)

Custom meta tags that should use property attribute instead of name

  • an array of strings or symbols representing their names or name-prefixes.

Returns:

  • (Array[String | Symbol])


40
41
42
# File 'lib/meta_tags/configuration.rb', line 40

def property_tags
  @property_tags
end

Configure whenever Meta-Tags should skip canonicals on pages with noindex: true "shouldn't mix noindex & rel=canonical comes from: they're very contradictory pieces of information for us."

Returns:

  • (Boolean)


46
47
48
# File 'lib/meta_tags/configuration.rb', line 46

def skip_canonical_links_on_noindex
  @skip_canonical_links_on_noindex
end

#title_limitInteger?

How many characters to truncate title to.

Returns:

  • (Integer, nil)


7
8
9
# File 'lib/meta_tags/configuration.rb', line 7

def title_limit
  @title_limit
end

#title_tag_attributesHash[html_tag_key, html_tag_value]?

HTML attributes for the title tag.

Returns:

  • (Hash[html_tag_key, html_tag_value], nil)


10
11
12
# File 'lib/meta_tags/configuration.rb', line 10

def title_tag_attributes
  @title_tag_attributes
end

#truncate_on_natural_separatorString?, Regexp

A string or regexp separator to truncate text at a natural break.

Returns:

  • (String?, Regexp)


16
17
18
# File 'lib/meta_tags/configuration.rb', line 16

def truncate_on_natural_separator
  @truncate_on_natural_separator
end

#truncate_site_title_firstBoolean

Truncate site_title instead of title.

Returns:

  • (Boolean)


13
14
15
# File 'lib/meta_tags/configuration.rb', line 13

def truncate_site_title_first
  @truncate_site_title_first
end

Instance Method Details

#default_property_tagsArray[String | Symbol]

Returns:

  • (Array[String | Symbol])


53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/meta_tags/configuration.rb', line 53

def default_property_tags
  [
    # App Link metadata https://developers.facebook.com/docs/applinks/metadata-reference
    "al",
    # Open Graph Markup https://developers.facebook.com/docs/sharing/webmasters#markup
    "fb",
    "og",
    # Facebook OpenGraph Object Types https://developers.facebook.com/docs/reference/opengraph
    # Note that these tags are used in a regex, so including e.g. 'restaurant' will affect
    # 'restaurant:category', 'restaurant:price_rating', and anything else under that namespace.
    "article",
    "book",
    "books",
    "business",
    "fitness",
    "game",
    "music",
    "place",
    "product",
    "profile",
    "restaurant",
    "video"
  ].freeze
end

#open_meta_tags?Boolean

Returns:

  • (Boolean)


78
79
80
# File 'lib/meta_tags/configuration.rb', line 78

def open_meta_tags?
  !!open_meta_tags
end

#reset_defaults!void

This method returns an undefined value.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/meta_tags/configuration.rb', line 82

def reset_defaults!
  @title_limit = 70
  @truncate_site_title_first = false
  @truncate_on_natural_separator = " "
  @title_tag_attributes = {}
  @description_limit = 300
  @keywords_limit = 255
  @keywords_separator = ", "
  @keywords_lowercase = true
  @property_tags = default_property_tags.dup
  @open_meta_tags = true
  @minify_output = false
  @skip_canonical_links_on_noindex = false
end